# (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
"""Command line script as simpler wrapper around paster"""

import sys

import paste.script.command


USAGE = """'nensskel' is a small wrapper around the 'paster create' command.

Basic usage: nensskel PROJECTNAME -t TEMPLATENAME [--svn-repository=URL]

PROJECTNAME is something like 'lizard_report' or 'turtlescripts' (without the
quotes, of course).

TEMPLATENAME is something like 'nens_library'.

URL is something like 'https://office.nelen-schuurmans.nl/svn/Products/'.
Nensskel creates a PROJECTNAME directory in there with trunk/tags/branches
structure.

These are the available templates (ignore basic_package and paste_deploy):
"""


def main():
    """Show usage msg when called without args, call paster otherwise.

    This method is installed by setup.py as the ``nensskel`` console_script.

    """
    args = sys.argv[1:]
    if len(args) == 0:
        print USAGE
        paste.script.command.run(['create', '--list-templates'])
    else:
        # Pass everything along to ``paster create``.
        args[0:0] = ['create']
        paste.script.command.run(args)



# (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from __future__ import print_function

# from django.db import models
# from django.utils.translation import ugettext_lazy as _

# Create your models here.



# (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from __future__ import print_function

from sitesetup.fab.config import init_file
from sitesetup.fab.tasks import *

# Most settings can be configured in fabfile.cfg
init_file('fabfile.cfg')



# (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
import os
import random
import sys

from paste.script import templates

from nensskel import utils

# Bloody hack for cheetah
reload(sys)
sys.setdefaultencoding('UTF-8')

CHARS = 'abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)'


class Lizardsite(templates.Template):
    _template_dir = 'templates/lizardsite'
    summary = "A buildout for nens lizard django sites"
    required_templates = ['nens_djangoapp']
    use_cheetah = True

    def run(self, command, output_dir, vars):
        secret = ''.join([random.choice(CHARS) for i in range(50)])
        vars['secret_key'] = secret
        db_password1 = ''.join([random.choice(CHARS) for i in range(10)])
        db_password2 = ''.join([random.choice(CHARS) for i in range(10)])
        vars['production_db_password'] = db_password1
        vars['staging_db_password'] = db_password2

        templates.Template.run(self, command, output_dir, vars)

    def post(self, command, output_dir, vars):
        testsettings = os.path.join(output_dir, vars['package'],
                                    'testsettings.py')
        os.remove(testsettings)
        testsettings_location = os.path.join(vars['package'],
                                             'testsettings.py')
        os.remove(os.path.join(output_dir, 'buildout.cfg'))
        utils.print_egginfo_removal_instructions(
            output_dir,
            vars,
            extra_reverts=[testsettings_location])



# (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
import os
import subprocess


def svn_propset(directory, ignores, setting='svn:ignore'):
    """If the directory is an svn dir, add ignores to svn:ignores"""
    if not os.path.exists(os.path.join(directory, '.svn')):
        # No svn dir, so we won't set anything.
        # This also applies if the dir doesn't even exists.
        return
    to_ignore = '\n'.join(ignores)
    # TODO: check if this works on windows.
    subprocess.call(['svn', 'propset', setting, to_ignore, directory])


def print_egginfo_removal_instructions(output_dir, vars, extra_reverts=None):
    """Print egg-info removal instructions."""
    if extra_reverts is None:
        extra_reverts = []
    using_svn = os.path.exists(os.path.join(output_dir, '.svn'))

    egginfo_dirname = '%(package)s.egg-info' % vars
    print
    print "Manual task that you need to do:"
    print "cd %s" % output_dir
    if using_svn:
        print "svn revert %s" % egginfo_dirname
        for extra_revert in extra_reverts:
            print "svn revert %s" % extra_revert
    print "rm -rf %s" % egginfo_dirname
    if not using_svn:
        # Assumption: git.
        print "git init"
        print "git add -A"
        print "git commit -m 'Generated with nensskel'"
        git_url = "git@github.com:%(github_organization)s/%(project)s.git"
        git_url = git_url % vars
        print "git remote add origin %s" % git_url
        print "git push -u origin master"
    print



from setuptools import setup

version = '1.36'

long_description = '\n\n'.join(
    [open('README.rst').read(),
     open('CHANGES.rst').read(),
     ]
)

install_requires = [
    'setuptools',
    'pkginfo',
    'Cheetah',
    'PasteScript>=1.6',
]

tests_require = [
    'nose',
    'coverage',
    'mock'
]


setup(
    name='nensskel',
    version=version,
    author='Reinout van Rees',
    author_email='reinout.vanrees@nelen-schuurmans.nl',
    url='http://pypi.python.org/pypi/nensskel',
    download_url='',
    description='Skeleton for Nelen & Schuurmans projects',
    long_description=long_description,
    license='GPL',
    packages=['nensskel'],
    include_package_data=True,
    zip_safe=False,
    install_requires=install_requires,
    tests_require=tests_require,
    extras_require={'test': tests_require},
    entry_points={
        'console_scripts': [
            'nensskel = nensskel.cmdline:main',
        ],
        'paste.paster_create_template': [
            'nens_library = nensskel.library:Library',
            'nens_djangoapp = nensskel.djangoapp:Djangoapp',
            'nens_lizardsite = nensskel.lizardsite:Lizardsite',
            'nens_leansite = nensskel.leansite:Leansite',
        ],
    },
)



# (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
import sys

from paste.script import templates

from nensskel import utils

# Bloody hack for cheetah
reload(sys)
sys.setdefaultencoding('UTF-8')


class Djangoapp(templates.Template):
    _template_dir = 'templates/djangoapp'
    summary = "A buildout for nens django applications"
    required_templates = ['nens_library']
    use_cheetah = True

    def post(self, command, output_dir, vars):
        utils.print_egginfo_removal_instructions(output_dir, vars)



# (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from __future__ import print_function

from django.test import TestCase


class ExampleTest(TestCase):

    def test_something(self):
        self.assertEquals(1, 1)



# (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
import os
import pkginfo
import sys

from paste.script import templates

from nensskel import utils

# Bloody hack for cheetah
reload(sys)
sys.setdefaultencoding('UTF-8')


class Library(templates.Template):
    _template_dir = 'templates/library'
    summary = "A buildout for nens libraries"
    required_templates = []
    use_cheetah = True

    def run(self, command, output_dir, vars):
        project = vars['project']
        if '_' in project:
            print "There's an underscore in the project name."
            print "Please use a dash instead."
            sys.exit(1)
        package = project
        if '-' in project:
            package = project.replace('-', '_')
            print "Project is called %s, the package will be %s" % (
                project, package)
        vars['package'] = package
        vars['nensskel_version'] = pkginfo.Installed('nensskel').version
        if 'lizard' in project:
            vars['github_organization'] = 'lizardsystem'
        else:
            vars['github_organization'] = 'nens'
        templates.Template.run(self, command, output_dir, vars)

    def post(self, command, output_dir, vars):
        """Clean up the result"""
        egginfo_dirname = '%(package)s.egg-info' % vars
        utils.svn_propset(output_dir,
                          ['.coverage',
                           '.installed.cfg',
                           'bin',
                           'coverage',
                           'coverage.xml',
                           'develop-eggs',
                           'eggs',
                           'htmlcov',
                           'nosetests.xml',
                           'parts',
                           'var',
                           egginfo_dirname])
        sphinx_dir = os.path.join(output_dir, 'doc')
        utils.svn_propset(sphinx_dir, ['build'])
        utils.print_egginfo_removal_instructions(output_dir, vars)
